//--------------------------------------------------------------------------------//
//-                   KJOs ( K-Junior Operating System )                         -//
//                                                                               -//
//-  Copyright (C) Frdric Lambercy, K-Team S.A. 2008                           -//
//-  This library is free software; you can redistribute it and/or               -//
//-  modify it under the terms of the GNU Lesser General Public                  -//
//-  License as published by the Free Software Foundation; either                -//
//-  version 2.1 of the License, or any later version.                           -//
//-                                                                              -//
//-  This library is distributed in the hope that it will be useful,             -//
//-  but WITHOUT ANY WARRANTY; without even the implied warranty of              -//
//-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU           -//
//-  Lesser General Public License for more details.                             -//
//-                                                                              -//
//-  You should have received a copy of the GNU Lesser General Public            -//
//-  License along with this library; if not, write to the Free Software         -//
//-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA   -//
//-                                                                              -//
//-                               __  __  ________                               -//
//- K-Team S.A.                  |  |/  /|__    __|___  _____  ___  ___          -//
//- Rue Galilee 9. Y-Park,       |     / __ |  | _____|/  _  \|   \/   |         -//
//- 1400 Yverdon-les-Bains       |  |  \    |  | ____|/  /_\  |        |         -//
//- Switzerland                  |__|\__\   |__|______|_/   \_|__|\/|__|         -//
//- lambercy@k-team.com   tel:+41 24 423 89 73 fax:+41 24 423 8960               -//
//-                                                                              -//
//--------------------------------------------------------------------------------//

////////////////////////////////////////////////////////////////////////////////
/*!   \file constants.h
      \brief In this file all constants are defined
*/
////////////////////////////////////////////////////////////////////////////////

#define INIT_TRISA            0x3F   // b0011 1111
#define INIT_PORTA            0x00   // b0000 0000

#define INIT_TRISB            0x1F   // b0001 1111
#define INIT_PORTB            0x00   // b0000 0000

#define INIT_TRISC            0x98   // b1000 1000
#define INIT_PORTC            0x00   // b0000 0000

#define INIT_TRISD            0x00   // b0000 0000
#define INIT_PORTD            0x00   // b0000 0000

#define INIT_TRISE            0xFF   // b1111 1111
#define INIT_PORTE            0x00   // b0000 0000

#BIT BOR = 0x8E.0
#BIT POR = 0x8E.1

#define SERIAL_BUFFER_SIZE  20

#define LEFT                  0
#define FRONTLEFT             1
#define FRONT                 2
#define FRONTRIGHT            3
#define RIGHT                 4
#define REAR                  5
#define GROUNDLEFT            9
#define GROUNDFRONTLEFT       10
#define GROUNDFRONTRIGHT      8
#define GROUNDRIGHT           11

#define IR_GROUP1             PIN_A7
#define IR_GROUP2             PIN_D2
#define IR_GROUP3             PIN_D3

#define LEFT_EMITTER                  PIN_A7
#define FRONTLEFT_EMITTER             PIN_D2
#define FRONT_EMITTER                 PIN_A7
#define FRONTRIGHT_EMITTER            PIN_D3
#define RIGHT_EMITTER                 PIN_A7
#define REAR_EMITTER                  PIN_D3
#define GROUNDLEFT_EMITTER            PIN_D2
#define GROUNDFRONTLEFT_EMITTER       PIN_D3
#define GROUNDFRONTRIGHT_EMITTER      PIN_D2
#define GROUNDRIGHT_EMITTER           PIN_D3


#define ENABLE                1
#define DISABLE               0
#define FAST                  1
#define NORMAL                0
#define MANUAL                0
#define REFRESH               1
#define ON                    1
#define OFF                   0

#define KJ_FW_VERSION   "A"
#define KJ_FW_REVISION  7                 // Please set revision!
#define KJ_FW_REFERENCE "510.0018"

#define LED_1            0x01
#define LED_2            0x02
#define LED_3            0x04
#define LED_4            0x08
#define LED_5            0x10
#define LED_ALL          0xFF

#define RC5_HEADER       0xC0
#define RC5_TOGGLE       0x20
#define MANCHESTER_0     0x2
#define MANCHESTER_1     0x1

#define RC5_KJ_ADDR      0x00             // RC5 address of the K-Junior robot ! it's a TV!
#define RC5_KJ_CMD_GO    0x02
#define RC5_KJ_CMD_BACK  0x00
#define RC5_KJ_CMD_LEFT  0x04
#define RC5_KJ_CMD_RIGHT 0x06
#define RC5_KJ_CMD_STOP  0x05
#define RC5_KJ_CMD_Sp    0x10             // Speed+ = Vol +
#define RC5_KJ_CMD_Sm    0x11             // Speed- = Vol -

#define StartBit1        0
#define StartBit2        1
#define ToggleBit        2
#define AddrBit4       3
#define AddrBit3       4
#define AddrBit2       5
#define AddrBit1       6
#define AddrBit0       7
#define DataBit5         8
#define DataBit4         9
#define DataBit3         10
#define DataBit2         11
#define DataBit1         12
#define DataBit0         13

#define MotD1           PIN_C1
#define MotD2           PIN_D0
#define MotG1           PIN_C2
#define MotG2           PIN_D1

#define BUZZER          PIN_D4

#define IR_IN           PIN_B0
#define IR_OUT          PIN_B5

#define LED0            PIN_D5
#define LED1            PIN_D6
#define LED2            PIN_D7
#define LED3            PIN_B6
#define LED4            PIN_B7

#define TIMER1_VALUE    65085
#locate INTCON =        0x000B
#locate PIR1   =        0x000C

