//--------------------------------------------------------------------------------//
//-                   KJOs ( K-Junior Operating System )                         -//
//                                                                               -//
//-  Copyright (C) Frdric Lambercy, K-Team S.A. 2008                           -//
//-  This library is free software; you can redistribute it and/or               -//
//-  modify it under the terms of the GNU Lesser General Public                  -//
//-  License as published by the Free Software Foundation; either                -//
//-  version 2.1 of the License, or any later version.                           -//
//-                                                                              -//
//-  This library is distributed in the hope that it will be useful,             -//
//-  but WITHOUT ANY WARRANTY; without even the implied warranty of              -//
//-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU           -//
//-  Lesser General Public License for more details.                             -//
//-                                                                              -//
//-  You should have received a copy of the GNU Lesser General Public            -//
//-  License along with this library; if not, write to the Free Software         -//
//-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA   -//
//-                                                                              -//
//-                               __  __  ________                               -//
//- K-Team S.A.                  |  |/  /|__    __|___  _____  ___  ___          -//
//- Rue Galilee 9. Y-Park,       |     / __ |  | _____|/  _  \|   \/   |         -//
//- 1400 Yverdon-les-Bains       |  |  \    |  | ____|/  /_\  |        |         -//
//- Switzerland                  |__|\__\   |__|______|_/   \_|__|\/|__|         -//
//- lambercy@k-team.com   tel:+41 24 423 89 73 fax:+41 24 423 8960               -//
//-                                                                              -//
//--------------------------------------------------------------------------------//

////////////////////////////////////////////////////////////////////////////////
/*!   \file variables.c
      \brief Definition of all global functions
*/
////////////////////////////////////////////////////////////////////////////////

//- Motors
signed int8 PwmMotLeft = 0;                                                     // 0 : Stop ; 20 : Max Speed
signed int8 PwmMotRight = 0;                                                    // 0 : Stop ; 20 : Max Speed
unsigned char PwmCounter = 0;

//- Configuration Bits
int1 Auto_Refresh_Sensors = 1;                                                  // 1 : Auto   ; 0 : Manual
int1 Auto_Refresh_TV_Remote = 1;                                                // 1 : Auto   ; 0 : Never
int1 Enable_RS232_Control = 1;                                                  // 1 : Enable ; 0 : Disable
int1 Enable_TV_Remote_Control = 1;                                              // 1 : Enable ; 0 : Disable



//- RS232
char SerialBuffer[ SERIAL_BUFFER_SIZE ];
int1 SerialCommandOK = 0;
char SerialCounter = 0;

//- Flag
int1 Sensors_Refreshed_Flag = 0;

//- TV Remote Control Bit
int8 TV_table[14];
int8 TV_ADDR = 0;                                                               // Address of the received RC5 code
int8 TV_DATA = 0;                                                               // Data of the received RC5 code
int8 TV_Counter = 0;                                                            // Counter for the RC5 code
int1 TV_Counter_flag = 0;                                                       // Flag to know if the emitting is in the first phase (=0) or the second (=1) of the bit to send
int8 TV_Data_send = 0;                                                          // Value of the rc5 code to send
int8 TV_Addr_send = 0;                                                          // Address of the rc5 code to send
int1 TV_Data_Available = 0;                                                     // Flag to indicate that a Data is available
int1 TV_Data_pending = 0;                                                       // Flag indicate that a data is coming on the IR receiver
int1 TV_Data_emitting = 0;                                                      // Flag indicate that a data must be send via the IR emitter
int1 TV_Data_loop = 0;                                                          // Flag to loop when a 1 is following by a zero



//- Time
unsigned int32 TimeTip = 0;
char TimeTipDivider = 0;

//- Irs Sensors
signed int16 IR_Light[ 12 ];
signed int16 IR_Proximity[ 12 ];                                              // 0 : nothing detected ; 1023 : obstacle near KJunior
unsigned char IR_Counter = 0 ;                                                  // counter to manage the refresh of the IR sensor
unsigned char IR_ADC_Flag = 0;                                                  // Flag to indicate when a sensor is completely refreshed
unsigned char IR_Pin_Table[12];                                                 // Table where the pin map of the IR sensor are saved
int1 Manual_Refresh_sensors = 0;                                                // Flag to refresh manually the sensor

//- Switchs
char Switchs;


//- LED state (0 = Normal, 1 = Mode auto activate (chenillard))
unsigned char LED_mode = 0x10;                                                  // Start with the LED4 in auto mode
unsigned int16 LED_counter = 0;

//- Buzzer variable
unsigned char buzzValue   = 0;                                                  // Value of the Buzzer frequency 
unsigned char buzzCounter   = 0;                                                // Counter to make the buzzer frequency

// Variable for Bluetooth configuration
unsigned char BT_config = 0;

//- TRIS
#locate TRISB = 0x0086



